@@ -15,6 +15,7 @@ import re
 
 from pyvows import Vows, VowsAssertionError
 
+
 @Vows.assertion
 def to_match(topic, expected):
     '''Asserts that `topic` matches the regular expression
@@ -22,7 +23,8 @@ def to_match(topic, expected):
 
     '''
     if not re.match(expected, topic):
-        raise VowsAssertionError('Expected topic(%s) to match the regular expression %s', topic, expected)
+        raise VowsAssertionError('Expected topic({0}) to match the regular expression {1}', topic, expected)
+
 
 @Vows.assertion
 def not_to_match(topic, expected):
@@ -31,5 +33,4 @@ def not_to_match(topic, expected):
 
     '''
     if re.match(expected, topic):
-        raise VowsAssertionError('Expected topic(%s) not to match the regular expression %s', topic, expected)
-
+        raise VowsAssertionError('Expected topic({0}) not to match the regular expression {1}', topic, expected)
